<?php

date_default_timezone_set("Europe/Paris");
 
$action = 0;
$country = "fr";
$region = "";
$ask_timestamp = null;
$return = null;
if (isset($argv[1])) {
  $action = intval($argv[1]);
}
if (isset($argv[2])) {
  $country = $argv[2];
}
if (isset($argv[3])) {
  $region = $argv[3];
  if ($region == "null") $region = "";
}
if (isset($argv[4])) {
  $ask_date = $argv[4];
  if (!empty($ask_date)) {
	$ask_timestamp = strtotime($ask_date);
    if ($ask_timestamp === false || $ask_timestamp == -1) $ask_timestamp = null;
  }
}

switch ($action) {
  case 2: // date du prochain jour férié
    $return = date("d/m/Y", getNextHoliday());
    break;
  case 1: // jour férié ?
	$return = isNotWorkable($ask_timestamp);
    break;
  case 0:
  default: // nb jour avant prochain jour férié
	$return = getDifftoNextHoliday();
    break;
}

echo $return;
exit();

/* Fonctions */
function isNotWorkable($timestamp=null)
{
  if ($timestamp === null)
  {
    $timestamp = strtotime("today");
  }

  $year = date("Y", $timestamp);
  $holidays = getHolidays($year);

  $return = in_array($timestamp, $holidays);
  return intval($return);
}

/*
* Cette fonction retourne un tableau de timestamp correspondant
* aux jours fériés en France pour une année donnée.
*/
function getHolidays($year=null)
{
  global $country, $region;
  if ($year === null) $year = date("Y");

  $easterDate  = easter_date($year);
  $easterDay   = date("j", $easterDate);
  $easterMonth = date("n", $easterDate);
  $easterYear	 = date("Y", $easterDate);

  $holidays = array();
  $antilles = false;
  if ($country == "fr")
  {
	// Dates fixes
	$holidays[] = mktime(0, 0, 0, 1,  1,  $year);  // 1er janvier
	$holidays[] = mktime(0, 0, 0, 5,  1,  $year);  // Fête du travail
	$holidays[] = mktime(0, 0, 0, 5,  8,  $year);  // Victoire des alliés 1945
	$holidays[] = mktime(0, 0, 0, 7,  14, $year);  // Fête nationale
	$holidays[] = mktime(0, 0, 0, 8,  15, $year);  // Assomption
	$holidays[] = mktime(0, 0, 0, 11, 1,  $year);  // Toussaint
	$holidays[] = mktime(0, 0, 0, 11, 11, $year);  // Armistice 1918
	$holidays[] = mktime(0, 0, 0, 12, 25, $year);  // Noel

	// Dates variables
	$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay + 1,  $easterYear); // Lundi de Paques
	$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay + 39, $easterYear); // Ascension
	$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay + 50, $easterYear); // Lundi Pentecote
	
	if ($region == "moselle" || $region == "bas-rhin" || $region == "haut-rhin") {
		$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay - 2,  $easterYear); // Vendredi Saint
		$holidays[] = mktime(0, 0, 0, 12, 26, $year);  // Saint Etienne
	} else if ($region == "martinique") {
		$holidays[] = mktime(0, 0, 0, 5, 22, $year);  // Abolition esclavage
		$antilles = true;
	} else if ($region == "guadeloupe") {
		$holidays[] = mktime(0, 0, 0, 5, 27, $year);  // Abolition esclavage
		$antilles = true;
	} else if ($region == "saint-martin") {
		$holidays[] = mktime(0, 0, 0, 5, 27, $year);  // Abolition esclavage
		$antilles = true;
	} else if ($region == "guyane") {
		$holidays[] = mktime(0, 0, 0, 6, 10, $year);  // Abolition esclavage
	} else if ($region == "saint-barthelemy") {
		$holidays[] = mktime(0, 0, 0, 10, 9, $year);  // Abolition esclavage
		$antilles = true;
	} else if ($region == "reunion") {
		$holidays[] = mktime(0, 0, 0, 12, 20, $year);  // Abolition esclavage
	}
	
	if (!empty($antilles)) {
		$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay - 47,  $easterYear); // Mardi Gras
		$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay - 46,  $easterYear); // Mercredi Gras
		$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay - 2,  $easterYear); // Vendredi Saint
		$holidays[] = mktime(0, 0, 0, 11, 2, $year);  // Fete des Morts
	}
  }
  else if ($country == "be")
  {
	// Dates fixes
	$holidays[] = mktime(0, 0, 0, 1,  1,  $year);  // 1er janvier
	$holidays[] = mktime(0, 0, 0, 5,  1,  $year);  // Fête du travail
	$holidays[] = mktime(0, 0, 0, 7,  21, $year);  // Fête nationale
	$holidays[] = mktime(0, 0, 0, 8,  15, $year);  // Assomption
	$holidays[] = mktime(0, 0, 0, 11, 1,  $year);  // Toussaint
	$holidays[] = mktime(0, 0, 0, 11, 11, $year);  // Armistice 1918
	$holidays[] = mktime(0, 0, 0, 12, 25, $year);  // Noel

	// Dates variables
	$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay + 1,  $easterYear); // Lundi de Paques
	$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay + 39, $easterYear); // Ascension
	$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay + 50, $easterYear); // Lundi Pentecote
  }
  else if ($country == "ch")
  {
	// Dates fixes
	$holidays[] = mktime(0, 0, 0, 1,  1,  $year);  // 1er janvier
	$holidays[] = mktime(0, 0, 0, 8,  1, $year);  // Fête nationale
	$holidays[] = mktime(0, 0, 0, 12, 25, $year);  // Noel
	
	// Dates variables
	$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay + 1,  $easterYear); // Lundi de Paques
 	$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay + 39, $easterYear); // Ascension
	$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay + 50, $easterYear); // Lundi Pentecote
	
	$canton_inarray = array(
		mktime(0, 0, 0, 1,  2,  $year) => array("AG", "BE", "FR", "GL", "JU", "LU", "NE", "OW", "SH", "SO", "VD", "ZG", "ZH"),
		mktime(0, 0, 0, 1,  6,  $year) => array("SZ", "TI", "UR"),
		mktime(0, 0, 0, 3,  1,  $year) => array("NE"),
		mktime(0, 0, 0, 3, 19,  $year) => array(/*"LU", */"NW", "SZ", "TI", "UR", "VS"), // LU demi journee ???
		mktime(0, 0, 0, 5,  1,  $year) => array("BL", "BS", "GE", "JU", "NE", "SH", "TI", "UR", "ZH"),
		mktime(0, 0, 0, 6, 23,  $year) => array("JU"),
		mktime(0, 0, 0, 6, 29,  $year) => array("TI"),
		mktime(0, 0, 0, 8, 15,  $year) => array("AG", "AI", "FR", "JU", "LU", "NW", "OW", "SO", "SZ", "TI", "UR", "VS", "ZG"),
		mktime(0, 0, 0, 9, 25,  $year) => array("OW"),
		mktime(0, 0, 0, 11, 1,  $year) => array("AG", "AI", "FR", "GL", "JU", "LU", "NW", "OW", "SG", "SO", "TI", "UR", "VS", "ZG"),
		mktime(0, 0, 0, 12, 8,  $year) => array("AG", "FR", "LU", "NW", "OW", "TI", "UR", "VS", "ZG"),
		mktime(0, 0, 0, 12,31,  $year) => array("GE")
	);
	$canton_outarray = array( // not in array
		mktime(0, 0, 0, $easterMonth, $easterDay - 2,  $easterYear) => array("TI", "VS"), // vendredi saint
		mktime(0, 0, 0, 12,26,  $year) => array("GE", "JU", "NE", "VD", "VS"), // saint etienne // NE si 25/12 dimanche
	);
	
	if ($region == "NE" && date("N", mktime(0, 0, 0, 12, 25, $year)) == 7) { // Si region NE et 25/12 dimanche
		$holidays[] = mktime(0, 0, 0, 12,26,  $year); // saint etienne
	}
	
	if ($region == "GL") {
//		mktime(0, 0, 0, 1,  1,  $year) => array("GL"), // fahrtsfest
		$holidays[] = strtotime("first thursday of april", mktime(0, 0, 0, 1,  1,  $year));
	}
	
	$fetedieu_array = array("AG", "AI", "FR", "JU", "LU", /*"NE", */"NW", "OW", "SO", "SZ", "TI", "UR", "VS", "ZG"); // NE 2 communes seulement
	if (in_array($region, $fetedieu_array)) {
		$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay + 60, $easterYear); // Jeudi qui suit le Dimanche de la Trinite (Dimanche qui suit la Pentecote)
	}
	
	if ($region == "GE") { // "jeune genevois" => array("GE")
		$firstdimofsept = strtotime("first sunday of september", mktime(0, 0, 0, 1,  1,  $year));
		$holidays[] = strtotime("+4 days", $firstdimofsept);
	}
	
	if ($region == "NE" || $region == "VD") { // "jeune federal" => array("NE", "VD")
		$thirddimofsept = strtotime("third sunday of september", mktime(0, 0, 0, 1,  1,  $year));
		$holidays[] = strtotime("+1 days", $thirddimofsept);
	}
  
	foreach($canton_inarray as $date => $inarray) {
		if (in_array($region, $inarray)) {
			$holidays[] = $date;
		}
	}
	foreach($canton_outarray as $date => $outarray) {
		if (!empty($region) && !in_array($region, $outarray)) {
			$holidays[] = $date;
		}
	}
  }
  else if ($country == "ca")
  {
	// Dates fixes
	$holidays[] = mktime(0, 0, 0, 1,  1,  $year);  // 1er janvier
	$holidays[] = strtotime("previous monday", mktime(0, 0, 0, 5, 25,  $year)); // Lundi avant la Fete de la Reine
	$holidays[] = mktime(0, 0, 0, 7,  1,  $year);  // Fête du Canada
	$holidays[] = strtotime("first monday of september", mktime(0, 0, 0, 1,  1,  $year)); // Fete du Travail
	$holidays[] = strtotime("second monday of october", mktime(0, 0, 0, 1,  1,  $year)); // Action de Grace
	$holidays[] = mktime(0, 0, 0, 12, 25, $year);  // Noel
	
	// Dates variables
	$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay - 2,  $easterYear); // Vendredi Saint
	$holidays[] = $easterDate;
	$holidays[] = mktime(0, 0, 0, $easterMonth, $easterDay + 1,  $easterYear); // Lundi de Paques
	
	if ($region == "QC") {
		if (date("N", mktime(0, 0, 0, 7, 1, $year)) == 7) { // Si 1/7 dimanche
			$holidays[] = mktime(0, 0, 0, 7, 2,  $year);
		}
		$holidays[] = mktime(0, 0, 0, 6, 24,  $year); // Fete nationale (Quebec)
	}
/*	if () {// Ville particuliere ???
		$holidays[] = strtotime("first monday of august", mktime(0, 0, 0, 1,  1,  $year)); // Fete Civique	
	}
*/
	if ($region != "QC") {
		$holidays[] = mktime(0, 0, 0, 11, 11, $year);  // Armistice 1918
	}
  }
  
  sort($holidays);

  return $holidays;
}

function nextHoliday($year=null)
{
  $now = time();
  $next_holiday = null;
  $holidays = getHolidays($year);
  foreach($holidays as $key => $holiday_timestamp) {
    if ($holiday_timestamp > $now) {
      $next_holiday = $holiday_timestamp;
      break;
    }
  }

  return $next_holiday;
}

function getNextHoliday()
{
  $next_holiday = nextHoliday(); // get first next holiday for current year
  if ($next_holiday === null) { // no holiday for current year
    $next_year = date("Y") + 1; // next year
    $next_holiday = nextHoliday($next_year); // get first next holiday for next year       	  
  }

  return $next_holiday;
}

function getDifftoNextHoliday($format="%a")
{
  $next_holiday = getNextHoliday();

  $date_next_holiday = date_create("@".strtotime("today", $next_holiday));
  $current_date = date_create("@".strtotime("today"));

  $diff = date_diff($current_date, $date_next_holiday);

  return $diff->format($format);
}

?>